#
# spec file for package python-pytest-ansible
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%if 0%{?suse_version} < 1550
# Leap15, SLES15
%if %pythons == "python310"
%define ansible_python python310
%define ansible_python_executable python3.10
%define ansible_python_sitelib %python310_sitelib
#
%define python_for_dependencies python310
%endif
%if %pythons == "python311"
%define ansible_python python311
%define ansible_python_executable python3.11
%define ansible_python_sitelib %python311_sitelib
#
%define python_for_dependencies python311
%endif
%else
# Tumbleweed
%define pythons python3
%define ansible_python python3
%define ansible_python_executable python3
%define ansible_python_sitelib %python3_sitelib
#
%define python_for_dependencies python311
%endif

Name:           python-pytest-ansible
Version:        25.1.0
Release:        1.1
Summary:        Plugin for pytest to simplify calling ansible modules from tests or fixtures
License:        MIT
URL:            https://github.com/ansible-community/pytest-ansible
Source:         pytest-ansible-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.10}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 63.0.0}
BuildRequires:  %{python_module setuptools_scm >= 7.0.5}
BuildRequires:  %{python_module wheel}
BuildRequires:  git-core
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  ansible-core >= 2.15.0
BuildRequires:  %{python_module pytest >= 6}
BuildRequires:  molecule >= 6.0.0
# /SECTION
BuildRequires:  fdupes
Requires:       %{python_for_dependencies}-packaging
Requires:       %{python_for_dependencies}-pytest >= 6
Requires:       ansible-core > 2.14
Requires:       python-ansible-compat >= 4.1.11
Suggests:       %{python_for_dependencies}-attrs == 22.2.0
Suggests:       %{python_for_dependencies}-iniconfig == 2.0.0
Suggests:       %{python_for_dependencies}-pluggy == 1.0.0
Suggests:       %{python_for_dependencies}-pytest == 7.2.2
BuildArch:      noarch
%python_subpackages

%description
Plugin for pytest to simplify calling ansible modules from tests or fixtures

%prep
%autosetup -p1 -n pytest-ansible-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
IGNORED_CHECKS="test_connection_failure_extra_inventory_v2"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_connection_failure_v2"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_contacted_with_params"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_contacted_with_params_and_host_pattern_marker"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_contacted_with_params_and_inventory_host_pattern_marker"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_contacted_with_params_and_inventory_marker"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_dark_with_debug_enabled"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_dark_with_params"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_dark_with_params_and_host_pattern_marker"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_dark_with_params_and_inventory_marker"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_molecule_disabled"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_molecule_runtest"

%pytest -k "not (${IGNORED_CHECKS})" -W ignore:'There is no current event loop'

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/pytest_ansible
%{python_sitelib}/pytest_ansible-%{version}.dist-info

%changelog
* Wed Jan 22 2025 opensuse_buildservice@ojkastl.de
- Update to version 25.1.0:
  * Bump the dependencies group in /.config with 8 updates (#420)
  * Bump the dependencies group in /.config with 5 updates (#419)
  * chore: pre-commit autoupdate (#417)
  * Bump the dependencies group in /.config with 6 updates (#416)
  * Bump the dependencies group in /.config with 9 updates (#415)
  * Bump the dependencies group in /.config with 9 updates (#414)
  * Bump the dependencies group in /.config with 5 updates (#413)
* Thu Dec 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 24.12.0:
  * Add support for py313 (#400) @ssbarnea
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 24.9.0:
  * Bump the dependencies group in /.config with 7 updates (#388)
  * Bump the dependencies group across 1 directory with 31 updates
    (#387)
  * chore: pre-commit autoupdate (#384)
  * Community comms (#383)
  * Bump cryptography from 43.0.0 to 43.0.1 in /.config (#385)
* Sat Aug 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 24.8.0:
  * Bump the dependencies group in /.config with 11 updates (#379)
  * chore: Update pyproject.toml (#378)
  * chore: pre-commit autoupdate (#377)
  * Bump the dependencies group in /.config with 8 updates (#376)
  * Don't report coverage on `_version.py.` This is only an issue
    when running locally but can be misleading when comparing to CI
    results. (#375)
  * Bump the dependencies group in /.config with 10 updates (#374)
  * Update to match common extensions. (#373)
  * Add initial sonarcloud configuration (#372)
  * REmove uneeded name (#371)
  * Update forum post (#370)
  * Update forum post (#369)
  * Add forum post (#368)
  * Update release workflow (#367)
  * Fix release workflow (#366)
  * Update release workflow (#365)
  * Formatting only (#363)
  * Bump the dependencies group in /.config with 10 updates (#362)
  * Bump the dependencies group in /.config with 10 updates (#361)
* Thu Jul 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 24.7.0:
  * Updated cspell dictionary and removed unneeded values (#359)
  * Bump the dependencies group in /.config with 6 updates (#357)
* Wed Jul  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 24.1.4:
  * Bump pylint from 3.2.4 to 3.2.5 in /.config in the dependencies
    group (#355)
  * Sort, lowercase and remove duplicates in .config/dictionary.txt
    (#354)
  * Remove flake8 (#351)
  * Bump the dependencies group across 1 directory with 3 updates
    (#353)
  * Resolve module to full qualified name (#352)
  * Bump the dependencies group in /.config with 7 updates (#349)
  * Add a couple safety pre-commit checks. (#348)
  * Move the coverage file into the .cache directory. (#347)
  * Move the coverage file into the .cache directory. (#346)
  * Bump the dependencies group in /.config with 10 updates (#345)
  * Add known first party (#344)
  * Wrap the long line so it will pass a default yamllint config
    (#343)
  * Move tool cache into cache directory to prevent root directory
    pollution. (#342)
  * Bump pipdeptree in /.config in the dependencies group (#332)
  * Ruff inline (#341)
  * Shift to per error exclusions (#340)
  * The tox workflow is called by release and therefore needs
    `workflow_call` (#339)
  * Allow manually running push for release note generation after a
    failed or reverted release. (#338)
  * Switch to pycontrib prettier (#335)
  * Update for coverage exclude (#331)
  * Sort, lowercase and remove duplicates in .config/dictionary.txt
    (#329)
  * Update codecov yaml file (#327)
  * Update depndabot config (#326)
  * Update cspell configuration file (#328)
  * Update pytest (#323)
  * Update ack to use org token (#324)
  * Update mypy configuration (#321)
  * Update pylint (#320)
  * Enable ruff with exceptions (#319)
  * Enable pydocstyle (#318)
  * Update VsCode files (#317)
  * Update precommit (#316)
  * Update tox.ini (#315)
  * Bump the dev group across 1 directory with 10 updates (#314)
  * Bump the runtime group in /.config with 2 updates (#312)
  * Use OIDC authentication for codecov (#311)
  * Bump the dev group in /.config with 7 updates (#310)
  * Bump the dev group in /.config with 7 updates (#309)
  * Bump jinja2 from 3.1.3 to 3.1.4 in /.config (#308)
  * chore: pre-commit autoupdate (#307)
  * Bump the dev group in /.config with 8 updates (#306)
  * Bump pytest from 8.1.1 to 8.2.0 in /.config in the runtime
    group (#303)
  * Bump the dev group in /.config with 8 updates (#304)
  * gha: rename reusable repository (#305)
* Tue Apr 23 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- fix wrong dependencies, even though this package might be called
  python3-pytest-ansible, most of the dependencies are called
  python311-XXX (with the current version Ansible and its ecosystem
  are building against)
* Tue Apr 23 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 24.1.3:
  * Bugfixes
  - Test Discovery considers global molecule config (#258) @M4rt1nCh
  - Silence incorrect warning message (#289) @AlanCoding
- use obs_scm instead of relying on PyPI tarballs without checksums
* Thu Jan 18 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 24.1.2:
  * Bugfixes
  - Adjust molecule command from cmdline (#254) @cristianonicolai
* Wed Jan 10 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 24.1.1:
  * Bugfixes
  - Added missing ansible-compat runtime dependency
    (#246) @ssbarnea
* Wed Jan 10 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 24.1.0 (using new version scheme):
  * Minor Changes
  - Require python 3.10 or newer (#231) @ssbarnea
  - Require ansible-core 2.14 or newer (#206) @ssbarnea
  * Bugfixes
  - Fix duplicated host bug with extra_inventory (#180) @CFSNM
  - Avoid use of deprecated pkg_resources (#220) @ssbarnea
  - Add getting started and installation steps to docs (#214)
    @cristianonicolai
  - Remove outdated-version-block (UP036) (#213)
    @cristianonicolai
  - Remove dead-code related to unsupported ansible versions
    (#208) @ssbarnea
  - Avoid early molecule importing (#210) @ssbarnea
  - Avoid accidental plugin activation (#202) @ssbarnea
  - Enable Ruff doc validation (#209) @cristianonicolai
  - Initial mkdocs setup (#199) @cristianonicolai
  - Add pydoclint to pre-commit config (#198) @cristianonicolai
  - Add Python 3.12 to project classifiers (#192)
    @cristianonicolai
  - Fix codecov configuration (#190) @ssbarnea
* Thu Oct 12 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 4.1.1:
  * Bugfixes
  - Enable CSpell check (#188) @cristianonicolai
  - Move coverage to `pyproject.toml` (#179) @Ruchip16
  - Add Python 3.12 to test matrix (#185) @cristianonicolai
  - Remove Flake8 and revisit initial config for Ruff (#186)
    @cristianonicolai
* Thu Sep 14 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 4.1.0:
  * Minor Changes
  - Add config option for ANSIBLE_COLLECTIONS_PATH (#163)
    @Ruchip16
  - Add tests for inventory (#164) @Ruchip16
  - Handle test markers (#167) @Ruchip16
  - todo fixes & __getattr__ method fix (#162) @Ruchip16
  * Bugfixes
  - Precommit update reqs (#172) @cidrblock
  - Handle test markers (#167) @Ruchip16
* Thu Sep  7 2023 Johannes Kastl <kastl@b1-systems.de>
- new package python-pytest-ansible: A pytest plugin that enables
  the use of ansible in tests, enables the use of pytest as a
  collection unit test runner, and exposes molecule scnearios
  through a pytest fixture
